Dyff 0.7.1 release
==================

- Reject more requests at the API server rather than waiting for backend components to report errors back. Should mean more immediate exceptions and less "workflow enters a failure state sometime later".

- Return :py:class:`~dyff.schema.platform.Status` from ``inferencesessions.terminate`` endpoint, for symmetry with ``delete`` endpoints.
